@@ -26,6 +26,7 @@ import yaml
 
 
 DELAY_BASE = 2.0
+MAX_REQUEST_ATTEMPTS = 6
 
 
 def random_string(
@@ -39,17 +40,18 @@ def random_string(
 class SpotifyConnector:
     """Representation of the inofficial Spotify podcast API."""
 
-    def __init__(self,
+    def __init__(
+        self,
         base_url,
         client_id,
         podcast_id,
         sp_dc,
         sp_key,
-     ):
+    ):
         """Initializes the SpotifyConnector object.
 
         Args:
-            base_url (str, optional): Base URL for the API. 
+            base_url (str, optional): Base URL for the API.
             client_id (str, optional): Spotify Client ID for the API.
             sp_dc (str, optional): Spotify cookie.
             sp_key (str, optional): Spotify cookie.
@@ -182,8 +184,7 @@ class SpotifyConnector:
     def _request(self, url: str, *, params: Optional[Dict[str, str]] = None) -> dict:
         logger.trace("url = {}", url)
         delay = DELAY_BASE
-        for attempt in range(6):
-            sleep(delay)
+        for attempt in range(MAX_REQUEST_ATTEMPTS):
             self._ensure_auth()
 
             # Create request object with requests and trace it before sending
@@ -206,6 +207,7 @@ class SpotifyConnector:
                     url,
                     delay,
                 )
+                sleep(delay)
                 continue
 
             elif response.status_code == 401:
@@ -224,27 +226,35 @@ class SpotifyConnector:
 
         raise Exception("All retries failed!")
 
-    def metadata(self) -> dict:
+    def metadata(self, episode=None) -> dict:
         """Loads metadata for podcast.
-        
+
         Args:
-            podcast_id (str): ID of the podcast to request data for.
-            
+            episode (str): ID of the episode to request data for (optional).
+              If this is not provided, data for all episodes will be returned.
+
         Returns:
             dict: Response data from API.
         """
-        url = self._build_url(
-           "shows",
-           self.podcast_id,
-           "metadata",
-        )
+        if episode is None:
+            url = self._build_url(
+                "shows",
+                self.podcast_id,
+                "metadata",
+            )
+        else:
+            url = self._build_url(
+                "episodes",
+                episode,
+                "metadata",
+            )
         return self._request(url)
 
     def streams(
         self,
         start: dt.date,
         end: Optional[dt.date] = None,
-        episode = None,
+        episode=None,
     ) -> dict:
         """Loads podcast/episode stream data, which includes the number of
         starts and completions for each episode.
@@ -280,7 +290,7 @@ class SpotifyConnector:
         self,
         start: dt.date,
         end: Optional[dt.date] = None,
-        episode = None,
+        episode=None,
     ) -> dict:
         """Loads podcast listener data, which includes the number of
         listeners for each episode.
@@ -312,11 +322,36 @@ class SpotifyConnector:
             )
         return self._request(url, params=self._date_params(start, end))
 
+    def followers(
+        self,
+        start: dt.date,
+        end: Optional[dt.date] = None,
+    ) -> dict:
+        """Loads podcast follower data.
+
+        Args:
+            start (dt.date): Earliest date to request data for.
+            end (Optional[dt.date], optional): Most recent date to request data for.
+              Defaults to None. Will be set to ``start`` if None.
+
+        Returns:
+            dict: [description]
+        """
+        if end is None:
+            end = start
+
+        url = self._build_url(
+            "shows",
+            self.podcast_id,
+            "followers",
+        )
+        return self._request(url, params=self._date_params(start, end))
+
     def aggregate(
         self,
         start: dt.date,
         end: Optional[dt.date] = None,
-        episode = None,
+        episode=None,
     ) -> dict:
         """Loads podcast aggregate data, which includes the number of
         starts and completions for each episode.
@@ -375,7 +410,7 @@ class SpotifyConnector:
             filter (str): Filter by field
 
         Returns:
-            (iterable): [episodes]
+            (iterable): [episode]
         """
         if end is None:
             end = start
@@ -389,7 +424,19 @@ class SpotifyConnector:
 
         # Yield each episode (handles pagination)
         while True:
-            response = self._request(url, params={**date_params, **{"page": page, "size": size, "sortBy": sortBy, "sortOrder": sortOrder, "filter": filter}})
+            response = self._request(
+                url,
+                params={
+                    **date_params,
+                    **{
+                        "page": page,
+                        "size": size,
+                        "sortBy": sortBy,
+                        "sortOrder": sortOrder,
+                        "filter": filter,
+                    },
+                },
+            )
             for episode in response["episodes"]:
                 yield episode
 
@@ -398,7 +445,6 @@ class SpotifyConnector:
 
             page += 1
 
-
     def performance(
         self,
         episode: str,
@@ -416,4 +462,4 @@ class SpotifyConnector:
             episode,
             "performance",
         )
-        return self._request(url)
\ No newline at end of file
+        return self._request(url)
